import { Component, ViewChild } from '@angular/core';
import { DataService } from 'src/services/data/data.service';
import { Weapon } from 'src/interfaces/weapon';
import { Spell } from 'src/interfaces/spell';
import { Damage } from 'src/interfaces/damage';
import { CdkDragDrop, moveItemInArray } from '@angular/cdk/drag-drop';
import { NgxSmartModalService, NgxSmartModalComponent } from 'ngx-smart-modal';
import { WeaponTableComponent } from './weapon-table/weapon-table.component';
import { SpellTableComponent } from './spell-table/spell-table.component';

@Component({
  selector: 'app-weapons-container',
  templateUrl: './weapons-container.component.html',
  styleUrls: ['./weapons-container.component.scss'],
})
export class WeaponsContainerComponent {
  public constructor(
    public dataAccessor: DataService,
    public ngxSmartModalService: NgxSmartModalService
  ) {}

  @ViewChild(WeaponTableComponent) weaponTable!: WeaponTableComponent;
  @ViewChild(SpellTableComponent) spellTable!: SpellTableComponent;

  public active: number = 1;

  public newWeaponName: string = '';
  public newWeaponDamageType: string = '';
  public newWeaponRange: string = '';
  public newWeaponAttackBonus: string = '';

  public newWeaponDamage: Damage[] = [
    { diceNumber: '', diceType: '', damageType: '' },
  ];

  public newWeaponProficient: boolean = false;
  public newWeaponAttribute: string = '';
  public newWeaponIsVersatile: boolean = false;
  public newWeaponIsTwoHanded: boolean = false;
  public newWeaponIsFinesse: boolean = false;
  public newWeaponIsRanged: boolean = false;
  public newWeaponVersatileDamage: Damage[] = [
    { diceNumber: '', diceType: '', damageType: '' },
  ];

  public newSpellName: string = '';
  public newSpellAttackBonus: string = '';
  public newSpellDamage: string = '';
  public newSpellType: string = '';
  public newSpellRange: string = '';
  public newSpellProficient: boolean = false;
  public newSpellAttribute: string = '';

  public spells!: Spell[];

  public ngOnInit(): void {
    this.spells = this.dataAccessor.getSpells();
  }

  public dropSpells(event: CdkDragDrop<string[]>): void {
    moveItemInArray(this.spells, event.previousIndex, event.currentIndex);
    this.updateSpells();
  }

  public updateSpells(): void {
    this.dataAccessor.setSpells(this.spells);
  }

  public addSpell(): void {
    // this.spells.push({
    //   name: this.newSpellName,
    //   damage: this.newSpellDamage,
    //   attackBonus: this.newSpellAttackBonus,
    //   range: this.newSpellRange,
    //   type: this.newSpellType,
    //   level: 0,
    //   attribute: this.newSpellAttribute,
    // });
    this.ngxSmartModalService.getModal('spellModal').close();
  }

  // spells

  public openSpellModal(): void {
    this.ngxSmartModalService.getModal('spellModal').open();
    console.log('openSpellModal()');
  }

  public addNewlyCreatedSpell(spell: Spell): void {
    this.spellTable.addSpell(spell);
  }

  // weapons
  public openWeaponModal(): void {
    console.log('openWeaponModal()');
    this.ngxSmartModalService.getModal('weaponModal').open();
  }

  public addNewlyCreatedWeapon(weapon: Weapon): void {
    this.weaponTable.addWeapon(weapon);
  }

  public log(): void {
    console.log('log');
  }
}
